using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace GenoProAutomation
{
  public partial class FormGenoProAutomation : Form
  {
    public FormGenoProAutomation()
    {
      InitializeComponent();
      Control.CheckForIllegalCrossThreadCalls = false;
    }

    private GenoPro.DocumentClass m_GenoProDocument; 

    private void cmdSendToGenoPro_Click(object sender, EventArgs e)
    {
      CreateGenoProInstanceIfNeeded();
      try {
        m_GenoProDocument.SetTextXML(txtSource.Text);
      } catch (System.Runtime.InteropServices.COMException) {
        // genopro has been probably closed and re-open, retry initialised.
        m_GenoProDocument = null;
        CreateGenoProInstanceIfNeeded();
        m_GenoProDocument.SetTextXML(txtSource.Text);
      }

      m_GenoProDocument.ShowWindow(); // bring GenoPro the active Windows
    }

    void m_GenoProDocument_OnDocumentSaving()
    {
      txtOutput.Text =   m_GenoProDocument.GetTextXML();  // Not thread safe
    }

    void m_GenoProDocument_OnDocumentClosing()
    {
      if (chkAutomaticGetXML.Checked) {
        txtOutput.Text = m_GenoProDocument.GetTextXML();
      }

    }

    private void SetText(string xml)
    {
      txtOutput.Text = xml;
    }

    private void cmdGetFromGenoPro_Click(object sender, EventArgs e)
    {
      CreateGenoProInstanceIfNeeded();
      try {
        txtOutput.Text = m_GenoProDocument.GetTextXML();
      } catch (Exception ex) {
        MessageBox.Show(ex.Message, "Cannot Get XML from GenoPro");
      }

    }

    private void CreateGenoProInstanceIfNeeded()
    {
      if (m_GenoProDocument == null) {
        m_GenoProDocument = new GenoPro.DocumentClass(); // create instance
        m_GenoProDocument.OnDocumentSaving += new GenoPro.IGenoDocumentEvents_OnDocumentSavingEventHandler(m_GenoProDocument_OnDocumentSaving);
        m_GenoProDocument.OnDocumentClosing += new GenoPro.IGenoDocumentEvents_OnDocumentClosingEventHandler(m_GenoProDocument_OnDocumentClosing);
      }
    }



  }
}